@@ -4,6 +4,8 @@
 #'
 #' @format This data frame contains the following columns:
 #' \describe{
+#'   \item{\code{version}}{Country code for the version of the show}
+#'   \item{\code{version_season}}{Version season key}
 #'   \item{\code{season_name}}{Season name}
 #'   \item{\code{season}}{Sesaon number}
 #'   \item{\code{location}}{Location of the season}
@@ -38,10 +40,12 @@
 #'
 #' @format This data frame contains the following columns:
 #' \describe{
+#'   \item{\code{version}}{Country code for the version of the show}
+#'   \item{\code{version_season}}{Version season key}
 #'   \item{\code{season}}{Sesaon number}
 #'   \item{\code{season_name}}{Season name}
 #'   \item{\code{full_name}}{Full name of the castaway}
-#'   \item{\code{castaway_id}}{ID of the castaway (primary key). Consistent across seasons and name changes e.g. Amber Brkich / Amber Mariano. The first two letters reference the country of the version played e.g. US, AU (TBA). To recreate the old ID simply extract the digits (See details)}
+#'   \item{\code{castaway_id}}{ID of the castaway (primary key). Consistent across seasons and name changes e.g. Amber Brkich / Amber Mariano. The first two letters reference the country of the version played e.g. US, AU (TBA).}
 #'   \item{\code{castaway}}{Name of castaway. Generally this is the name they were most commonly referred to
 #'   or nickname e.g. no one called Coach, Benjamin. He was simply Coach}
 #'   \item{\code{age}}{Age of the castaway during the season they played}
@@ -54,12 +58,6 @@
 #'   \item{\code{result}}{Final result}
 #'   \item{\code{jury_status}}{Jury status}
 #'   \item{\code{original_tribe}}{Original tribe name}
-#'   \item{\code{swapped_tribe}}{Swapped tribe name}
-#'   \item{\code{swapped_tribe_2}}{Second swapped tribe in the event of a second tribe swap or other tribe restructure such as absorbed tribe, outcasts, etc}
-#'   \item{\code{merged_tribe}}{Merged tribe name}
-#'   \item{\code{total_votes_received}}{Total number of tribal votes received during the main game for a given season
-#'   (not overall for those who have played more than once). This includes votes from ties}
-#'   \item{\code{immunity_idols_won}}{The number of immunity idols won by a castaway for the given season}
 #' }
 #'
 #' @details If the original \code{castaway_id} is desired simply extract the digits from the ID e.g.
@@ -80,7 +78,7 @@
 #'
 #' @format This data frame contains the following columns:
 #' \describe{
-#'   \item{\code{castaway_id}}{ID of the castaway (primary key). Consistent across seasons and name changes e.g. Amber Brkich / Amber Mariano. The first two letters reference the country of the version played e.g. US, AU (TBA). To recreated the old ID simply extract teh digits}
+#'   \item{\code{castaway_id}}{ID of the castaway (primary key). Consistent across seasons and name changes e.g. Amber Brkich / Amber Mariano. The first two letters reference the country of the version played e.g. US, AU (TBA).}
 #'   \item{\code{full_name}}{Full name of the castaway}
 #'   \item{\code{short_name}}{Short name of the castaway. Name typically used during the season. Sometimes there are multiple
 #'   people with the same name e.g. Rob C and Rob M in Survivor All-Stars. This field takes the most verbose name used}
@@ -114,12 +112,14 @@
 #'
 #' @format This data frame contains the following columns:
 #' \describe{
+#'   \item{\code{version}}{Country code for the version of the show}
+#'   \item{\code{version_season}}{Version season key}
 #'   \item{\code{season_name}}{The season name}
 #'   \item{\code{season}}{The season number}
 #'   \item{\code{castaway}}{Name of the castaway}
 #'   \item{\code{finalist}}{The finalists for which a vote can be placed}
 #'   \item{\code{vote}}{Vote. 0-1 variable for easy summation}
-#'   \item{\code{castaway_id}}{ID of the castaway (primary key). Consistent across seasons and name changes e.g. Amber Brkich / Amber Mariano. The first two letters reference the country of the version played e.g. US, AU. To recreated the old ID simply extract teh digits}
+#'   \item{\code{castaway_id}}{ID of the castaway (primary key). Consistent across seasons and name changes e.g. Amber Brkich / Amber Mariano. The first two letters reference the country of the version played e.g. US, AU.}
 #'   \item{\code{finalist_id}}{The ID of the finalist for which a vote can be placed. Consistent with castaway ID}
 #' }
 #' @source \url{https://en.wikipedia.org/wiki/Survivor_(American_TV_series)}
@@ -138,20 +138,27 @@
 #'
 #' @format This data frame contains the following columns:
 #' \describe{
+#'   \item{\code{version}}{Country code for the version of the show}
+#'   \item{\code{version_season}}{Version season key}
 #'   \item{\code{season_name}}{The season name}
 #'   \item{\code{season}}{The season number}
 #'   \item{\code{episode}}{Episode number}
 #'   \item{\code{day}}{Day the tribal council took place}
 #'   \item{\code{tribe_status}}{The status of the tribe e.g. original, swapped, merged, etc. See details for more}
+#'   \item{\code{tribe}}{Tribe name}
 #'   \item{\code{castaway}}{Name of the castaway}
 #'   \item{\code{immunity}}{Type of immunity held by the castaway at the time of the vote e.g. individual,
 #'   hidden (see details for hidden immunity data)}
 #'   \item{\code{vote}}{The castaway for which the vote was cast}
+#'   \item{\code{vote_event}}{Extra details on the vote e.g. Won or lost the fire challenge, played an extra vote, etc}
+#'   \item{\code{split_vote}}{If there was a decision to split the vote this records who the vote was split with.
+#'   Helps to identify successful boots}
 #'   \item{\code{nullified}}{Was the vote nullified by a hidden immunity idol? Logical}
+#'   \item{\code{tie}}{If the set of votes resulted in a tie. Logical}
 #'   \item{\code{voted_out}}{The castaway who was voted out}
 #'   \item{\code{order}}{Boot order. Order in which castaway was voted out e.g. 5 is the 5th person voted of the island}
 #'   \item{\code{vote_order}}{In the case of ties this indicates the order the votes took place}
-#'   \item{\code{castaway_id}}{ID of the castaway (primary key). Consistent across seasons and name changes e.g. Amber Brkich / Amber Mariano. The first two letters reference the country of the version played e.g. US, AU. To recreated the old ID simply extract teh digits}
+#'   \item{\code{castaway_id}}{ID of the castaway (primary key). Consistent across seasons and name changes e.g. Amber Brkich / Amber Mariano. The first two letters reference the country of the version played e.g. US, AU.}
 #'   \item{\code{vote_id}}{ID of the castaway voted for}
 #'   \item{\code{voted_out_id}}{ID of the castaway voted_out}
 #' }
@@ -207,6 +214,8 @@
 #'
 #' @format This data frame contains the following columns:
 #' \describe{
+#'   \item{\code{version}}{Country code for the version of the show}
+#'   \item{\code{version_season}}{Version season key}
 #'   \item{\code{season_name}}{The season name}
 #'   \item{\code{season}}{The season number}
 #'   \item{\code{tribe}}{Tribe name}
@@ -249,6 +258,8 @@
 #'
 #' @format This data frame contains the following columns:
 #' \describe{
+#'   \item{\code{version}}{Country code for the version of the show}
+#'   \item{\code{version_season}}{Version season key}
 #'   \item{\code{season_name}}{The season name}
 #'   \item{\code{season}}{Season number}
 #'   \item{\code{episode_number_overall}}{The cumulative episode number}
@@ -276,53 +287,6 @@
 #' @source \url{https://en.wikipedia.org/wiki/Survivor_(American_TV_series)}
 "season_palettes"
 
-#' Challenges
-#'
-#' (Deprecated) The challenges data set has been superseded by two new data sets \code{challenge_results} and
-#' \code{challenge_description}.
-#'
-#' @format This nested data frame contains the following columns:
-#' \describe{
-#'   \item{\code{season_name}}{The season name}
-#'   \item{\code{season}}{The season number}
-#'   \item{\code{episode}}{Episode number}
-#'   \item{\code{day}}{The day of the tribal council}
-#'   \item{\code{challenge_type}}{The challenge type e.g. immunity, reward, etc}
-#'   \item{\code{challenge_name}}{[under development] Name of the challenge played (TBA)}
-#'   \item{\code{outcome_type}}{Whether the challenge is individual or tribal. Some individual reward challenges may involve multiple castawats as the winner gets to choose who they bring along}
-#'   \item{\code{winners_id}}{The ID of the winners of the challenge. Consistent with \code{castaway_id}}
-#'   \item{\code{winners}}{The list of winners. Either the list of people in the tribe which won, list of people that participated on the reward or the individual winner}
-#'   \item{\code{winning_tribe}}{Name of the winner tribe. \code{NA} during the merge}
-#' }
-#'
-#' @details A nested tidy data frame of immunity and reward challenge results. The
-#' winners and winning tribe of the challenge are found by expanding the `winners`
-#' column. For individual immunity challenges the winning tribe is simply `NA`.
-#'
-#' Typically in the merge if a single person win a reward they are allowed to bring
-#' others along with them. The first castaway in the expanded list is likely to be the
-#' winner and the subsequent players those they brought along with them. Although,
-#' not always. Occasionally in the merge the castaways are split into two teams for
-#' the purpose of the reward, in which case all castaways win the reward rather than
-#' a single person.
-#'
-#' The `day` field on this data set represents the day of the tribal council rather
-#' than the day of the challenge. This is to more easily associate the reward challenge
-#' with the immunity challenge and result of the tribal council. It also helps for
-#' joining tables.
-#'
-#' Note the challenges table is the combined immunity and rewards tables which will
-#' eventually be dropped in later releases.
-#'
-#' @source \url{https://en.wikipedia.org/wiki/Survivor_(American_TV_series)}
-#' @examples
-#' library(dplyr)
-#' library(tidyr)
-#' challenges %>%
-#'   filter(season == 40) %>%
-#'   unnest(winners)
-"challenges"
-
 #' Challenge Results
 #'
 #' A dataset detailing the challenges played including reward and immunity challenges.
@@ -334,6 +298,8 @@
 #'   \item{\code{season}}{The season number}
 #'   \item{\code{episode}}{Episode number}
 #'   \item{\code{day}}{The day of the tribal council}
+#'   \item{\code{order}}{The number of boots that there have been in the game e.g. if `order == 2` there have been 2
+#'   boots in the game so far and there are N-2 castaways left in the game}
 #'   \item{\code{episode_title}}{Episode title}
 #'   \item{\code{challenge_name}}{The name of the challenge. Challenges can go by different names but where possible
 #'   recurring challenges are kept consistent. While there are tweaks to the challenges where the main components of
@@ -420,36 +386,63 @@
 #'
 #' @format This data frame contains the following columns:
 #' \describe{
+#'   \item{\code{version}}{Country code for the version of the show}
+#'   \item{\code{version_season}}{Version season key}
 #'   \item{\code{season_name}}{The season name}
 #'   \item{\code{season}}{The season number}
 #'   \item{\code{episode}}{Episode number}
 #'   \item{\code{day}}{The day of the tribal council}
-#'   \item{\code{castaway_id}}{ID of the castaway (primary key). Consistent across seasons and name changes e.g. Amber Brkich / Amber Mariano. The first two letters reference the country of the version played e.g. US, AU. To recreated the old ID simply extract teh digits}
+#'   \item{\code{castaway_id}}{ID of the castaway (primary key). Consistent across seasons and name changes e.g. Amber Brkich / Amber Mariano. The first two letters reference the country of the version played e.g. US, AU.}
 #'   \item{\code{castaway}}{Name of the castaway}
 #'   \item{\code{tribe}}{Name of the tribe the castaway was on}
 #'   \item{\code{tribe_status}}{The status of the tribe e.g. original, swapped, merged, etc. See details for more}
 #' }
 #'
-#' @details Each season by day holds a complete list of castaways still in the game and
+#' @details Each season by episode and day holds a complete list of castaways still in the game and
 #' which tribe they are on. Moving through each day you can observe the changes in
-#' the tribe. For example the first day (usual day 2) has all castaways mapped to their
+#' the tribe. For example the first day has all castaways mapped to their
 #' original tribe. The next day has the same minus the castaway just voted out. This
 #' is useful for observing the changes in tribe make either due to castaways being voted
-#' off the island, tribe swaps or otherwise.
+#' off the island, tribe swaps, who is on Redemption Island and Edge of Extinction.
 #'
 #' @source \url{https://en.wikipedia.org/wiki/Survivor_(American_TV_series)}
 "tribe_mapping"
 
-#' Hidden Immunity Idols
+#' Boot mapping
 #'
-#' A dataset containing the history of hidden immunity idols including who found them,
-#' on what day and which day they were played.
+#' A mapping table for easily filtering to the set of castaways that are still in the game
+#' after a specified number of boots.
+#'
+#' @format This data frame contains the following columns:
+#' \describe{
+#'   \item{\code{version}}{Country code for the version of the show}
+#'   \item{\code{version_season}}{Version season key}
+#'   \item{\code{season_name}}{The season name}
+#'   \item{\code{season}}{The season number}
+#'   \item{\code{episode}}{Episode number}
+#'   \item{\code{order}}{The number of boots that there have been in the game e.g. if `order == 2` there have been 2
+#'   boots in the game so far and there are N-2 castaways left in the game}
+#'   \item{\code{castaway_id}}{ID of the castaway (primary key). Consistent across seasons and name changes e.g. Amber Brkich / Amber Mariano. The first two letters reference the country of the version played e.g. US, AU.}
+#'   \item{\code{castaway}}{Name of the castaway}
+#'   \item{\code{tribe}}{Name of the tribe the castaway was on}
+#'   \item{\code{tribe_status}}{The status of the tribe e.g. original, swapped, merged, etc. See details for more}
+#'   \item{\code{in_the_game}}{Logical flag to identify if the castaway is currently in the game. If `FALSE` the castaway
+#'   is on Redemption Island or Edge of Extinction.}
+#' }
+#'
+#' @source \url{https://en.wikipedia.org/wiki/Survivor_(American_TV_series)}
+"boot_mapping"
+
+#' (Deprecated) Hidden Immunity Idols
+#'
+#' This data set has be replaced with the advantage data sets which contain more details
+#' and easier to use structure
 #'
 #' @format This data frame contains the following columns:
 #' \describe{
 #'   \item{\code{season_name}}{The season name}
 #'   \item{\code{season}}{The season number}
-#'   \item{\code{castaway_id}}{ID of the castaway (primary key). Consistent across seasons and name changes e.g. Amber Brkich / Amber Mariano. The first two letters reference the country of the version played e.g. US, AU. To recreated the old ID simply extract teh digits}
+#'   \item{\code{castaway_id}}{ID of the castaway (primary key). Consistent across seasons and name changes e.g. Amber Brkich / Amber Mariano. The first two letters reference the country of the version played e.g. US, AU.}
 #'   \item{\code{castaway}}{Name of the castaway}
 #'   \item{\code{idol_number}}{Indicates whether it is the first, second, etc idol found in the season}
 #'   \item{\code{idols_held}}{The number of idols held by the castaway}
@@ -469,11 +462,76 @@
 #'
 #' @format This data frame contains the following columns:
 #' \describe{
+#'   \item{\code{version}}{Country code for the version of the show}
+#'   \item{\code{version_season}}{Version season key}
 #'   \item{\code{season_name}}{The season name}
 #'   \item{\code{season}}{The season number}
 #'   \item{\code{episode}}{Episode number}
 #'   \item{\code{castaway}}{Name of the castaway}
-#'   \item{\code{castaway_id}}{ID of the castaway (primary key). Consistent across seasons and name changes e.g. Amber Brkich / Amber Mariano. The first two letters reference the country of the version played e.g. US, AU. To recreated the old ID simply extract teh digits}
+#'   \item{\code{castaway_id}}{ID of the castaway (primary key). Consistent across seasons and name changes e.g. Amber Brkich / Amber Mariano. The first two letters reference the country of the version played e.g. US, AU.}
 #'   \item{\code{confessional_count}}{The count of confessionals for the castaway during the episode}
 #' }
+#'
+#' @details Confessional data has been counted by contributors of the survivoR R package and consolidated
+#' with external sources. The aim is to establish consistency in confessional counts in the absence of official
+#' sources. Given the subjective nature of the counts and the potential for clerical error no single source is
+#' more valid than another. Therefore, it is reasonable to average across all sources.
+#'
+#' In the case of double or extended episodes, if the episode only has one title it is considered a single episode. This
+#' means the average number of confessionals per person is likely to be higher for this episode given it's length. If
+#' there are two episode titles the confessionals are counted for the appropriate episode. This is to ensure consistency
+#' across all other datasets.
+#'
+#' In the case of recap episodes, this episode is left blank.
+#'
+#' If you also count confessionals, please get in touch and I'll add them into the package.
 "confessionals"
+
+#' Advantage Movement
+#'
+#' A dataset containing the movement details of each advantage or hidden immunity idol. Each row
+#' is considered an event e.g. the idol was found, played, etc. If the advantage changed hands
+#' it records who received it. The logical flow is identified by the `sequence_id`.
+#'
+#' @format This data frame contains the following columns:
+#' \describe{
+#'   \item{\code{version}}{Country code for the version of the show}
+#'   \item{\code{version_season}}{Version season key}
+#'   \item{\code{season_name}}{The season name}
+#'   \item{\code{season}}{The season number}
+#'   \item{\code{castaway}}{Name of the castaway involved in the event e.g. found, played, received, etc.}
+#'   \item{\code{castaway_id}}{ID of the castaway (primary key). Consistent across seasons and name changes e.g. Amber Brkich / Amber Mariano. The first two letters reference the country of the version played e.g. US, AU.}
+#'   \item{\code{advantage_id}}{The ID / primary key of the advantage}
+#'   \item{\code{sequence_id}}{The sequnnce of events. For example `sequence_id == 1` usually means the advantage was found. Each subsequent event follows the `sequence_id`}
+#'   \item{\code{day}}{The day the event occured}
+#'   \item{\code{episode}}{The episode the event occured}
+#'   \item{\code{event}}{The event e.g. the advantage was found, played, received, etc}
+#'   \item{\code{played_for}}{If the advantage or idol was played this records who it was played for}
+#'   \item{\code{played_for_id}}{the ID for who the advantage or idol was played for}
+#'   \item{\code{success}}{If the play was succesful or not. Only relavent for advantages since playing a hidden immunity idol is always sucessful in terms of saving who it was played for.}
+#'   \item{\code{votes_nullified}}{In the case of hidden immunity idols this is the count of how many votes were nullified when played}
+#' }
+"advantage_movement"
+
+#' Advantage Details
+#'
+#' A dataset containing the details and characteristics of each idol and advantage. This maps to `advantage_movement`
+#'
+#' @format This data frame contains the following columns:
+#' \describe{
+#'   \item{\code{version}}{Country code for the version of the show}
+#'   \item{\code{version_season}}{Version season key}
+#'   \item{\code{season_name}}{The season name}
+#'   \item{\code{season}}{The season number}
+#'   \item{\code{advantage_id}}{The ID / primary key of the advantage}
+#'   \item{\code{advantage_type}}{Advantage type e.g. hidden immunity idol, extra vote, steal a vote, etc}
+#'   \item{\code{clue_details}}{Details if a clue existed for the advantage and if so where was the clue found}
+#'   \item{\code{location_found}}{The location the idol or advantage was found}
+#'   \item{\code{conditions}}{Extra details about the unique conditions of the idol or advantage}
+#' }
+#'
+#' @details There are split idols which need to be combined to be played. In these case the first one found is
+#' given an ID. The second or subsequent parts are given the same ID with a trailing letter. For example in season 40
+#' Denise found an idol that was split (USHI4002). Later she found the other half (USHI4002b). When played the second half is
+#' considered to have 'absorbed' into the first idol. The first idol found is always considered the primary idol.
+"advantage_details"
